
local addon, AR = ...;
local L=AR.L;
local autoConfirm = {};
AR.ModeLabels = {[0]=PASS,[1]=GREED,[2]=NEED --[[,[3]=DISENCHANT]]};
AR.default_items = {
	[120945] = 2, -- Primal Spirit
};

AutoRollDB = {
	enabled = true,
	items = AR.default_items,
};

local itemNames = {};
local function updateItemNames()
	wipe(itemNames);
	for i,v in pairs(AutoRollDB.items)do
		local name=GetItemInfo(i);
		if(name)then
			itemNames[name] = v;
		end
	end
end

-- addon setup
local main = CreateFrame("Frame", "AutoRollFrame");

main:RegisterEvent("ADDON_LOADED");

main:SetScript("OnEvent", function(self, event, arg1, arg2)

	if(event=="ADDON_LOADED" and addon==arg1)then
		print("|Cff3388ff"..addon,"|Cffffff00"..L["Addon loaded..."].."|r");
		print("|cff3388ff"..addon,"|cffffff00"..L["Addon"],(AutoRollDB.enabled and L["enabled"] or L["disabled"]) .. "...|r");
		if(AutoRollDB.enabled)then
			self:RegisterEvent("START_LOOT_ROLL");
			self:RegisterEvent("CONFIRM_LOOT_ROLL");
			updateItemNames();
		end
	end

	-- auto need on certain items
	if(event=="START_LOOT_ROLL")then
		-- search the lootframes for the item and click "need"
		for i = 1, NUM_GROUP_LOOT_FRAMES do
			-- Currently ElvUI is unsupportable. (ElvUI's own lootFrame objects have no framenames or connection to its parent (ElvUIParent) like parentKeys)
			local _, name, _, _, _, canNeed, canGreed, canDisenchant, reasonNeed, reasonGreed, reasonDisenchant = GetLootRollItemInfo(arg1)
			local lootFrame = _G["GroupLootFrame"..i];
			if(lootFrame:IsVisible() and itemNames[name])then
				if(reasonNeed or reasonGreed or reasonDisenchant)then
					autoConfirm[arg1]=true;
				end
				if(canNeed and itemNames[name]==2)then
					lootFrame.NeedButton:Click();
				elseif canGreed and (itemNames[name]==1) or (itemNames[name]==2 and not canNeed)then
					lootFrame.GreedButton:Click();
				end
			end
		end
	end

	-- confirm roll automatical
	if(event=="CONFIRM_LOOT_ROLL")then
		if(autoConfirm[arg1])then
			ConfirmLootRoll(arg1, arg2);
			autoConfirm[arg1]=nil;
		end
	end
end)


-- command line options
SlashCmdList["AUTOROLL"] = function(cmd)
	local cmd, arg = strsplit(" ", cmd:lower(), 2)

	local n, name = tonumber(arg);

	if(n)then
		name=GetItemInfo(n);
	end

	print("|Cff0088ff"..addon.."|r");
	if(cmd=="")then
		print(L["Chat command list for /ar & /autoroll"]);
		print(L["toggle - enable/disable AutoRoll's functionality"]);
		print(L["list - list items"]);
		print(L["add <itemId> - add an item to the item list"]);
		print(L["del <itemId> - delete an item from the item list"]);
		print(L["mode <itemId> - change need/greed mode for a single item"]);
		print(L["reset - reset the item list to default"]);
	elseif(cmd=="toggle")then
		AutoRollDB.enabled = not AutoRollDB.enabled;
		print(L["AutoRoll's functionality"] .. " " .. (AutoRollDB.enabled and L["enabled"] or L["disabled"]));
	elseif(cmd=="list")then
		print(L["Current item list"]);
		for i,v in pairs(AutoRollDB.items)do
			local name=GetItemInfo(i);
			print(L["Id: %d (%s), Mode: %s"]:format(i,name,(v==2 and NEED) or (v==1 and GREED) or "?"));
		end
	elseif(cmd=="add" and n~=nil and n>0 and not AutoRollDB.items[n])then
		local name=GetItemInfo(n);
		if(name)then
			AutoRollDB.items[n]=1;
			print(L["ItemID %d found... %s added to AutoRoll's item list. Mode: "..NEED]:format(n,name));
		else
			print(L["ItemID %d unknown/invalid... please check the given numbers."]:format(n));
		end
		updateItemNames();
	elseif(cmd=="del")then
		if(n~=nil and AutoRollDB.items[n])then
			AutoRollDB.items[n] = nil;
			print(L["ItemID %d (%s) removed from AutoRoll's item list"]:format(n,name));
		else
			print(L["Id %d not found in item list."]:format(n));
		end
		updateItemNames();
	elseif(cmd=="mode")then
		if(n and n>0 and AutoRollDB.items[n])then
			AutoRollDB.items[n] = AutoRollDB.items[n]==2 and 1 or 2;
			print(L["Changed mode for itemId %d (%s) to %s"]:format(n, name, AutoRollDB.items[n]==2 and NEED or GREED));
		else
			print(L["Id %d not found in item list."]:format(n));
		end
	elseif(cmd=="reset")then
		AutoRollDB.items = AR.default_items;
		updateItemNames();
		print(L["Item list resetted..."]);
	end

end

SLASH_AUTOROLL1 = "/autoroll"
SLASH_AUTOROLL2 = "/ar"

