
local addon, AR, panel = ...;
local L=AR.L;

---------------------------------------------------------------
---------------------------------------------------------------

local function TooltipOnEnter(self)
	if (self.tooltipText) then
		GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT")
		GameTooltip:SetText(self.tooltipText, nil, nil, nil, nil, 1)
		GameTooltip:Show()
	end
end

local function TooltipOnLeave(self)
	GameTooltip:Hide()
end

local function setPoints(frame,points)
	if(points==true)then
		frame:SetAllPoints();
	elseif(points)then
		for _,point in ipairs(points)do
			frame:SetPoint(unpack(point));
		end
	else
		frame:SetPoint("TOPLEFT");
	end
end

local function updateItemRow(button, index, data)
	local Name, _, Rarity, _, _, _, _, _, _, Texture = GetItemInfo(index);
	
	button.ItemID:SetText(index);
	button.ItemIcon:SetTexture(Texture);
	button.ItemName:SetText(Name);
	button.ItemName:SetPoint("RIGHT",button.Mode,"LEFT",-10,0);

	button.Mode.value=data;
	button.Mode.index=index;

	UIDropDownMenu_SetWidth(button.Mode, 90);
	UIDropDownMenu_Initialize(button.Mode, function()
		for v,t in pairs(AR.ModeLabels) do
			local info = UIDropDownMenu_CreateInfo();
			info.value,info.text,info.arg1,info.arg2=v,t,button.Mode,v;
			info.func = function(self,frame,value)
				UIDropDownMenu_SetSelectedValue(frame, value);
				panel.changes["item."..button.Mode.index]=value;
			end
			UIDropDownMenu_AddButton(info);
		end
	end);

	UIDropDownMenu_SetSelectedValue(button.Mode, data);

	local b=_G[button.Mode:GetName().."Button"];
	b:SetHitRectInsets(-(button.Mode:GetWidth()-(b:GetWidth()*2)),-3,-3,-3)
end

local function updateScrollFrame(self)
	local offset = HybridScrollFrame_GetOffset(self);

	local nEntries, entries = #self.data, nil;
	if(nEntries==0)then
		entries = {};
		for i, v in pairs(self.data)do
			table.insert(entries,i);
		end
		nEntries = #entries;
	end

	for i=1, #self.buttons do
		local index = offset+i;
		local button = self.buttons[i];

		if(entries and entries[index])then
			self.rowFnc(button,entries[index],self.data[entries[index]]);
			button:Show();
		elseif(not entries and self.data[index])then
			self.rowFnc(button,index,self.data[index]);
			button:Show();
		else
			button:Hide();
		end
	end

	HybridScrollFrame_Update(self, nEntries * self.buttonHeight, #self.buttons * self.buttonHeight);
end

local function createText(name, text, font, points, justifyH, justifyV, color)
	panel[name] = panel:CreateFontString(nil, "ARTWORK", font or "GameFontNormal");
	panel[name]:SetText(text);
	panel[name]:SetJustifyH(justifyH or "LEFT");
	panel[name]:SetJustifyV(justifyV or "TOP");
	setPoints(panel[name],points);
	if(color)then
		panel[name]:SetTextColor(unpack(color));
	end
end

local function createScrollFrame(name, data, rowFnc, rowTemplate, points)
	panel[name.."InsetFrame"] = CreateFrame("Frame", nil, panel);
	setPoints(panel[name.."InsetFrame"],points);
	panel[name.."InsetFrame"]:SetBackdrop({
		bgFile="Interface\\TutorialFrame\\TutorialFrameBackground",
		edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border",
		tile=true,
		tileSize=32,
		edgeSize=20,
		insets={left=4,right=4,top=4,bottom=4}
	});

	panel[name] = CreateFrame("ScrollFrame", panel:GetName().."_"..name, panel[name.."InsetFrame"], "BasicHybridScrollFrameTemplate");
	setPoints(panel[name],{
		{"TOPLEFT", 4, -4},
		{"BOTTOMRIGHT", -28, 8}
	});

	panel[name].scrollBar.doNotHide=true;
	panel[name].scrollBar:SetPoint("BOTTOMLEFT",panel[name],"BOTTOMRIGHT", 0, 12)

	panel[name].data = data;
	panel[name].rowFnc = rowFnc;
	panel[name].update = updateScrollFrame;
	HybridScrollFrame_CreateButtons(panel[name], rowTemplate, 2, -2, nil, nil, 0, -0);
end

---------------------------------------------------------------
---------------------------------------------------------------

panel = CreateFrame("Frame", addon .. "_Panel", InterfaceOptionsFramePanelContainer);
panel:SetAllPoints();
panel:Hide();
panel.name, panel.controls, panel.changes = addon, {}, {};

function panel:okay()
	for i,v in pairs(panel.changes)do
		local item=tonumber(i:match("^item(%d+)$"));
		if(item)then
			AutoRollDB.items[item] = v;
		else
			AutoRollDB[i] = v;
		end
	end
end

function panel:cancel()
	wipe(panel.changes);
end

function panel:default()
	AutoRollDB = {};
	ReloadUI();
end

function panel:refresh()
	for i,v in pairs(panel.controls)do
		if(v:GetObjectType()=="CheckButton")then
			--v:SetChecked(v.chkFunction);
		end
	end
end

panel:SetScript("OnShow", function()
	createText("title",addon.." - "..L["Options"],"GameFontNormalLarge",{{"TOPLEFT", panel, 12, -12}});
	--createText("subTitle","","GameFontHighlightSmall",{{"TOPLEFT", panel.title, "BOTTOMLEFT", 0, -4}});
	
	createScrollFrame(
		"itemList",
		AutoRollDB.items,
		updateItemRow,
		"AutoRoll_ButtonTemplate",
		{
			{"TOPLEFT", panel.title, "BOTTOMLEFT", 0, -26},
			{"BOTTOMRIGHT", -14, 80}
		}
	);

	updateScrollFrame(panel.itemList);

	panel:SetScript("OnShow",panel.refresh);
end);

InterfaceOptions_AddCategory(panel);
